@@ -435,6 +435,7 @@ static char *get_job_condition(char *src, edg_wll_QueryRec *cond)
 	else if ( !strcmp(tmps, "last_update_time") ) cond->attr = EDG_WLL_QUERY_ATTR_LASTUPDATETIME;
 	else if ( !strcmp(tmps, "jdl_attr") ) cond->attr = EDG_WLL_QUERY_ATTR_JDL_ATTR;
 	else if ( !strcmp(tmps, "job_type") ) cond->attr = EDG_WLL_QUERY_ATTR_JOB_TYPE;
+	else if ( !strcmp(tmps, "vm_status") ) cond->attr = EDG_WLL_QUERY_ATTR_VM_STATUS; 
 
 
        /**< When entered current status */
@@ -549,12 +550,20 @@ static char *get_job_condition(char *src, edg_wll_QueryRec *cond)
 			cond->value2.t.tv_sec = StrToTime(tmps);
 		}
 		break;
+
 	case EDG_WLL_QUERY_ATTR_JOB_TYPE:
 		if ( 0 > (cond->value.i = edg_wll_JobtypeStrToCode(tmps))) {
 			fprintf(stderr,"%s: invalid job type (%s)\n", myname, tmps);
 			return 0;
 		}
 		break;
+	
+	case EDG_WLL_QUERY_ATTR_VM_STATUS:
+		if ( 0 > (cond->value.i = edg_wll_StringToVMStat(tmps))) {
+			fprintf(stderr,"%s: invalid VM status value (%s)\n", myname, tmps);
+			return 0;
+		}
+		break;
 
 	default:
 		break;
@@ -774,30 +783,7 @@ static void printconds(edg_wll_QueryRec **cond)
 		{
 			if ( j )
 				printf(" OR ");
-			switch ( cond[i][j].attr )
-			{
-			case EDG_WLL_QUERY_ATTR_JOBID: printf("jobid"); break;
-			case EDG_WLL_QUERY_ATTR_OWNER: printf("owner"); break;
-			case EDG_WLL_QUERY_ATTR_STATUS: printf("status"); break;
-			case EDG_WLL_QUERY_ATTR_LOCATION: printf("location"); break;
-			case EDG_WLL_QUERY_ATTR_DESTINATION: printf("destination"); break;
-			case EDG_WLL_QUERY_ATTR_DONECODE: printf("done_code"); break;
-			case EDG_WLL_QUERY_ATTR_EXITCODE: printf("exit_code"); break;
-			case EDG_WLL_QUERY_ATTR_PARENT: printf("parent_job"); break;
-			case EDG_WLL_QUERY_ATTR_RESUBMITTED: printf("resubmitted"); break;
-			case EDG_WLL_QUERY_ATTR_USERTAG: printf("%s",cond[i][j].attr_id.tag); break;
-			case EDG_WLL_QUERY_ATTR_TIME: printf("time"); break;
-			case EDG_WLL_QUERY_ATTR_STATEENTERTIME: printf("state_enter_time"); break;
-			case EDG_WLL_QUERY_ATTR_LASTUPDATETIME: printf("last_update_time"); break;
-			case EDG_WLL_QUERY_ATTR_JDL_ATTR: printf("jdl_attr"); break;
-			case EDG_WLL_QUERY_ATTR_LEVEL: printf("level"); break;
-			case EDG_WLL_QUERY_ATTR_HOST: printf("host"); break;
-			case EDG_WLL_QUERY_ATTR_SOURCE: printf("source"); break;
-			case EDG_WLL_QUERY_ATTR_INSTANCE: printf("instance"); break;
-			case EDG_WLL_QUERY_ATTR_EVENT_TYPE: printf("ev_type"); break;
-			case EDG_WLL_QUERY_ATTR_JOB_TYPE: printf("job_type"); break;
-			default: break;
-			}
+			printf("%s", edg_wll_QueryAttrNames[cond[i][j].attr]);
 			switch ( cond[i][j].op )
 			{
 			case EDG_WLL_QUERY_OP_EQUAL: printf("="); break;
