@@ -124,4 +124,6 @@
 	VM_ID
 	VM_NAME
 	VM_PHY_HOSTNAME
+	VM_SYSTEM_HALTING
+	VM_MANAGER
 /;
